==> nextcloud-21.0.8p0.tgz: nextcloud/apps/password_policy/l10n/eo.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Tiu pasvorto troveblas inter la miliono da pli kutimaj pasvortoj.",
    "Password is present in compromised password list. Please choose a different password." : "Tiu pasvorto ĉeestas en la listo de malsekretigitaj pasvortoj. Bv. elekti alian pasvorton.",
    "Password needs to contain at least one numeric character." : "Pasvorto necesas enhavi almenaŭ unu nombran signon.",
    "Password needs to contain at least one special character." : "Pasvorto necesas enhavi almenaŭ unu specialan signon.",
    "Password needs to contain at least one lower and one upper case character." : "Pasvorto necesas enhavi almenaŭ unu minusklan kaj unu majusklan signon.",
    "Password policy" : "Pasvorta regularo",
    "Allows admins to configure a password policy" : "Ebligas al administranto difini regularon pri pasvortoj",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ebligas al administranto difini certajn regulojn pri pasvortoj, ekz. difini minimuman longon.",
    "Forbid common passwords" : "Malpermesi kutimajn pasvortojn",
    "Enforce upper and lower case characters" : "Devigi uzon de minuskloj kaj majuskloj",
    "Enforce numeric characters" : "Devigi uzon de signoj nombraj",
    "Enforce special characters" : "Devigi uzon de signoj specialaj",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kompari la pasvorton kun la listo de diskonigitaj pasvortoj el haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Tio kreas haketon el la pasvorto kaj sendas la unuajn 5 signojn de tiu haketo al la API de haveibeenpwned.com por ricevi liston de ĉiuj haketoj, kiuj komenciĝas per tiuj. Poste, ĝi kontrolas en la Nextcloud-servilo, ĉu la pasvorta haketo estas en la listo.",
    "Password needs to be at least %s characters long" : "Pasvorto necesas esti almenaŭ longa je %s signoj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/password_policy/l10n/eo.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Tiu pasvorto troveblas inter la miliono da pli kutimaj pasvortoj.",
    "Password is present in compromised password list. Please choose a different password." : "Tiu pasvorto ĉeestas en la listo de malsekretigitaj pasvortoj. Bv. elekti alian pasvorton.",
    "Password needs to contain at least one numeric character." : "Pasvorto necesas enhavi almenaŭ unu nombran signon.",
    "Password needs to contain at least one special character." : "Pasvorto necesas enhavi almenaŭ unu specialan signon.",
    "Password needs to contain at least one lower and one upper case character." : "Pasvorto necesas enhavi almenaŭ unu minusklan kaj unu majusklan signon.",
    "Password policy" : "Pasvorta regularo",
    "Allows admins to configure a password policy" : "Ebligas al administranto difini regularon pri pasvortoj",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ebligas al administranto difini certajn regulojn pri pasvortoj, ekz. difini minimuman longon.",
    "Saved" : "Konservita",
    "Forbid common passwords" : "Malpermesi kutimajn pasvortojn",
    "Enforce upper and lower case characters" : "Devigi uzon de minuskloj kaj majuskloj",
    "Enforce numeric characters" : "Devigi uzon de signoj nombraj",
    "Enforce special characters" : "Devigi uzon de signoj specialaj",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kompari la pasvorton kun la listo de diskonigitaj pasvortoj el haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Tio kreas haketon el la pasvorto kaj sendas la unuajn 5 signojn de tiu haketo al la API de haveibeenpwned.com por ricevi liston de ĉiuj haketoj, kiuj komenciĝas per tiuj. Poste, ĝi kontrolas en la Nextcloud-servilo, ĉu la pasvorta haketo estas en la listo.",
    "Unknown error" : "Nekonata eraro"
},
"nplurals=2; plural=(n != 1);");
